@@ -59,7 +59,7 @@ def _get_hub_ref() -> str:
     return contracted, frame.f_lineno
 
 
-def _get_logger(hub, name: str = "") -> aiologger.Logger:
+def _get_logger(hub, name: str = ""):
     if name not in hub.log.LOGGER:
         hub.log.LOGGER[name]: aiologger.Logger = aiologger.Logger(
             name=name, loop=hub.pop.Loop
